# eric7.Globals.__init__

Module defining common data to be used by all modules.

### Global Attributes

recentNameBreakpointConditions
recentNameBreakpointFiles
recentNameFiles
recentNameHexFiles
recentNameHosts
recentNameMultiProject
recentNamePdfFiles
recentNameProject
recentNameTestDiscoverHistory
recentNameTestEnvironment
recentNameTestFileHistory
recentNameTestFramework
recentNameTestNameHistory
settingsNameGlobal
settingsNameOrganization
settingsNameRecent

### Classes

None

### Functions

getInstallInfoFilePath | Public method to get the path name of the install info file.
getWebBrowserSupport | Module function to determine the supported web browser variant.

## getInstallInfoFilePath

getInstallInfoFilePath()

Public method to get the path name of the install info file.

Return:
  file path of the install info file

Return Type:
  str

Up

## getWebBrowserSupport

getWebBrowserSupport()

Module function to determine the supported web browser variant.

Return:
  string indicating the supported web browser variant ("QtWebEngine", or "None")

Return Type:
  str

Up